package query

import (
	"encoding/json"
	"github.com/odysseus/service-registry/common"
	"github.com/odysseus/service-registry/registry"
	"github.com/redis/go-redis/v9"
)

type BackendInfo struct {
	Timestamp int64  `redis:"timestamp" json:"timestamp"`
	Endpoint  string `redis:"endpoint" json:"endpoint"`
}

func (g BackendInfo) TimeStamp() int64 {
	return g.Timestamp
}

func (g BackendInfo) Message() json.RawMessage {
	d, _ := json.Marshal(g)
	return d
}

func (g BackendInfo) Parse(res *redis.MapStringStringCmd) ServiceInfo {
	var info BackendInfo
	var regInfo registry.RegistryInfo
	if err := res.Scan(&regInfo); err != nil {
		return nil
	}

	if err := json.Unmarshal([]byte(regInfo.Detail), &info); err != nil {
		return nil
	}
	info.Timestamp = regInfo.Timestamp
	info.Endpoint = regInfo.Endpoint
	return info
}

type backendQuery struct {
	baseService
}

func getBackendQuery(rdb *redis.Client) ServiceQuery {
	return backendQuery{
		baseService{
			rdb:     rdb,
			service: common.SERVICE_BACKEND,
		},
	}
}
