package query

import (
	"encoding/json"
	"github.com/odysseus/service-registry/common"
	"github.com/odysseus/service-registry/registry"
	"github.com/redis/go-redis/v9"
)

type SchedulerInfo struct {
	Timestamp int64  `redis:"timestamp" json:"timestamp"`
	Endpoint  string `redis:"endpoint" json:"endpoint"`
	Status    string `redis:"status" json:"status"`
}

func (g SchedulerInfo) TimeStamp() int64 {
	return g.Timestamp
}

func (g SchedulerInfo) Message() json.RawMessage {
	d, _ := json.Marshal(g)
	return d
}

func (g SchedulerInfo) Parse(res *redis.MapStringStringCmd) ServiceInfo {
	var info SchedulerInfo
	var regInfo registry.RegistryInfo
	if err := res.Scan(&regInfo); err != nil {
		return nil
	}

	if err := json.Unmarshal([]byte(regInfo.Detail), &info); err != nil {
		return nil
	}
	info.Timestamp = regInfo.Timestamp
	info.Endpoint = regInfo.Endpoint
	return info
}

type schedulerQuery struct {
	baseService
}

func getSchedulerQuery(rdb *redis.Client) ServiceQuery {
	return schedulerQuery{
		baseService{
			rdb:     rdb,
			service: common.SERVICE_SCHEDULER,
		},
	}
}
