package query

import (
	"encoding/json"
	"github.com/odysseus/service-registry/common"
	"github.com/odysseus/service-registry/registry"
	"github.com/redis/go-redis/v9"
)

type WorkerInfo struct {
	Timestamp      int64    `redis:"timestamp" json:"timestamp"`
	Endpoint       string   `redis:"endpoint" json:"endpoint"`
	HearBeat       int64    `redis:"heartbeat" json:"heartbeat"`
	ActiveNM       []string `redis:"active_nm" json:"active_nm"`
	MinerAddress   string   `redis:"miner_address" json:"miner_address"`
	BenefitAddress string   `redis:"benefit_address" json:"benefit_address"`
	IPs            []string `redis:"ip_list" json:"ip_list"`
	Status         string   `redis:"status" json:"status"`
}

func (g WorkerInfo) TimeStamp() int64 {
	return g.Timestamp
}

func (g WorkerInfo) Message() json.RawMessage {
	d, _ := json.Marshal(g)
	return d
}

func (g WorkerInfo) Parse(res *redis.MapStringStringCmd) ServiceInfo {
	var info WorkerInfo
	var regInfo registry.RegistryInfo
	if err := res.Scan(&regInfo); err != nil {
		return nil
	}

	if err := json.Unmarshal([]byte(regInfo.Detail), &info); err != nil {
		return nil
	}
	info.Timestamp = regInfo.Timestamp
	info.Endpoint = regInfo.Endpoint
	return info
}

type workerQuery struct {
	baseService
}

func getWorkerQuery(rdb *redis.Client) ServiceQuery {
	return workerQuery{
		baseService{
			rdb:     rdb,
			service: common.SERVICE_WORKER,
		},
	}
}
